# CHANGELOG


## v0.1.0 (2026-05-19)

### Features

- Enforce supabase mfa validation on fastapi dependencies
  ([`b82806a`](https://github.com/20206205Tech/20206205tech-python-auth/commit/b82806a92f2d04bd1325904fdc93a29a238e46d6))


## v0.0.0 (2026-05-10)
